declare module 'cpp' {
    namespace Cpp {
      /**
       * Interface encapsulating the various crypto computations used by the library,
       * allowing pluggable underlying crypto implementations.
       */
      export interface CryptoProvider {
        /**
         * Computes a SHA-256 HMAC given a secret and a payload (encoded in UTF-8).
         * The output HMAC should be encoded in hexadecimal.
         *
         * Sample values for implementations:
         * - computeHMACSignature('', 'test_secret') => 'f7f9bd47fb987337b5796fdc1fdb9ba221d0d5396814bfcaf9521f43fd8927fd'
         * - computeHMACSignature('\ud83d\ude00', 'test_secret') => '837da296d05c4fe31f61d5d7ead035099d9585a5bcde87de952012a78f0b0c43
         */
        computeHMACSignature: (payload: string, secret: string) => string;

        /**
         * Computes a Base64 SHA-256 HMAC given a secret and a payload (encoded in UTF-8).
         * The output HMAC should be encoded in base64.
         *
         * Sample values for implementations:
         * - computeHMACSignatureBase64('MerchantId: test_merchantId\nTimestamp: Fri, 22 Oct 2021 07:47:52 GMT\nHash: L129LTg3vyjndMYSxnjJj4KFatleaMsgqwvEjTTRsEI=', 'test_secret') => 'K/X3nd8VXMHlR1WvjLqtOZ6exOuizocFSvrz44uga6I='
         */
        computeHMACSignatureBase64: (payload: string, secret: string) => string;

        /**
         * Computes a Base64 SHA-256 HASH given a payload (encoded in UTF-8).
         * The output HASH should be encoded in base64.
         *
         * Sample values for implementations:
         * - computeHashBase64('{"txnType":"purchase","totalAmount":"14126.47","currencyCode":"NZD","clientRef":"35245245452345","tokenizeCard":false}') => 'L129LTg3vyjndMYSxnjJj4KFatleaMsgqwvEjTTRsEI='
         */
        computeHashBase64: (payload: string) => string;

        /**
         * Computes SHA-256 hash and signed SHA-256 HMAC headers given a secret, a payload, and headers (encoded in UTF-8).
         * The output is an object consisting merchantId, hash and signature.
         *
         * Sample values for implementations:
         * - generateSignedAuthHeader('test_merchantId', 'Fri, 22 Oct 2021 07:47:52 GMT','test_secret') => '{merchantId: 'test_merchantId', hash: 'L129LTg3vyjndMYSxnjJj4KFatleaMsgqwvEjTTRsEI=', sign: 'K/X3nd8VXMHlR1WvjLqtOZ6exOuizocFSvrz44uga6I='}'
         */
        generateSignedAuthHeader: (merchantId: string, timestamp: string, payload: string, sharedSecret: string) => object;
      }
    }
  }
  